@@ -39,7 +39,7 @@ class ConfigurationService(object):
 
     lock = threading.Lock()
 
-    def __init__(self, watch=False):
+    def __init__(self, watch=False, start_notification=False):
         self._clear()
         self.watch = watch # Watch configuration file changes
         self.parser = None
@@ -48,11 +48,12 @@ class ConfigurationService(object):
         # start notification service
         self.notify_wm = None
         self.notifier = None
+        self.notifier_started = False
         if watch and not have_pyinotify:
             raise RuntimeError('The "pyinotify" module must be installed '
                                'for using watch=True')
         if self.watch and have_pyinotify:
-            self.notify_mask = (EventsCodes.IN_MODIFY 
+            self.notify_mask = ( EventsCodes.IN_MODIFY 
                                | EventsCodes.IN_DELETE 
                                | EventsCodes.IN_ATTRIB 
                                | EventsCodes.IN_CREATE 
@@ -61,7 +62,8 @@ class ConfigurationService(object):
             event_handler = NotificationEvent()
             event_handler.setService(self) # needed for callback
             self.notifier = ThreadedNotifier(self.notify_wm, event_handler)
-            self.notifier.start()
+            if start_notification:
+                self.start()
 
     @synchronized(lock)
     def _clear(self):
@@ -127,6 +129,34 @@ class ConfigurationService(object):
         self.opts = opts
         self.parser = parser
 
+    ############################################################
+    # Notifier thread handling
+    ############################################################
+
+    def start(self):
+        """ Start notification thread """
+
+        if self.notifier is not None:
+            self.notifier.start()
+            self.notifier_started = True
+        else:
+            raise RuntimeError('Notification thread can not be started')
+
+    def shutdown(self):
+        """ Explict shutdown of the notifier thread (basically required for
+            Zope integration).
+        """
+
+        if self.notifier is not None:
+            if not self.notifier_started:
+                raise RuntimeError('Notifier thread is not started')
+            self.notifier.stop()
+            self.notifier_started = False
+
+    ############################################################
+    # Option/configuration lookup
+    ############################################################
+
     def get(self, name, domain=None):
         """ Return the value of a configuration option for a given key.
             'name' is either a full dotted name or added to a dotted
@@ -148,14 +178,6 @@ class ConfigurationService(object):
                 del opts[opt]
         return opts
 
-    def shutdown(self):
-        """ Explict shutdown of the notifier thread (basically required for
-            Zope integration).
-        """
-
-        if self.notifier is not None:
-            self.notifier.stop()
-
 
 class ConfigurationServiceFactory(object):
     """ Factory for the configuration service """
